@@ -437,13 +437,19 @@ def preprocessing_output_directory(output_directory):
 
         files = os.listdir(output_directory)
         # file name like: hostname-20210913175500.log.tar.gz
-        # sort by time
-        files.sort(key=lambda x: x.split('-')[1].split('.')[0], reverse=True)
+        # hostname may contain '-'
+        # get time by regular, sort by time
+        files.sort(key=lambda x: re.search(r"\d{14}", x).group())
+
+        # delete all the oldest files if the number of files is larger than 10
+        if len(files) >= 10:
+            for file in files[:-9]:
+                os.remove(os.path.join(output_directory, file))
+
+        return output_directory
+
+
 
-        for file in files:
-            file_full_path = os.path.join(output_directory, file)
-            if os.path.isfile(file_full_path):
-                os.remove(file_full_path)
     except Exception as error:
         print(error)
 
@@ -453,6 +459,7 @@ def upload_to_obs(upload_file):
     try:
         # ask if want to upload to obs
         # print beautiful box around the tip in terminal
+
         # the box length should auto adjust to the length of the tip
 
 
